@@ -4,7 +4,7 @@ RDF::Trine::Serializer::NTriples::Canonical - Canonical representation of an RDF
 
 =head1 VERSION
 
-This document describes RDF::Trine::Serializer::NTriples::Canonical version 0.122
+This document describes RDF::Trine::Serializer::NTriples::Canonical version 0.123
 
 =head1 SYNOPSIS
 
@@ -55,14 +55,13 @@ use warnings;
 
 use Carp;
 use RDF::Trine;
-
-our @ISA = qw();
+use base qw(RDF::Trine::Serializer::NTriples);
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.122';
+	$VERSION	= '0.123';
 	$RDF::Trine::Serializer::serializer_names{ 'ntriples-canonical' }	= __PACKAGE__;
 # 	foreach my $type (qw(text/plain)) {
 # 		$RDF::Trine::Serializer::media_types{ $type }	= __PACKAGE__;
